# Any Template

![GitHub](https://img.shields.io/github/license/Adwaith-Rajesh/any-template?style=for-the-badge&color=light-green)
![PyPI](https://img.shields.io/pypi/v/any-template?color=light-green&style=for-the-badge)
![GitHub Workflow Status](https://img.shields.io/github/workflow/status/Adwaith-Rajesh/any-template/Pypi-Upload?label=PYPI%20UPLOAD&style=for-the-badge)

A faster easier to Quick start any programming project.

## Installation

```commandline
pip3 install any-template
```

## Features

- No third party dependencies.
- Templates are not stored locally.

## Usage

- Create a folder where you want all the file to be generated, and `cd` into it.

- ### Using a template

  ```commandline
  anytemp use python-simple-package
  ```

  - Also initialize a git repo
    ```commandline
    anytemp use python-simple-package --git
    ```

- ### Listing all the available templates
  ```commandline
  anytemp ls
  ```
- ### Listing all the templates that contains a specific word
  ```commandline
  anytemp ls -c python
  ```

## Contributing

Contributing is the only way by which this package can grow. So if you have some sort of templates that you use on a daily basis feel free to add it here.
